@@ -455,6 +455,7 @@ class Recipe(object):
         # Create the settings files for the project
         self.create_file(os.path.join(project_dir, 'settings.py'), settings_template, template_vars, overwrite = True)
         self.create_file(os.path.join(project_dir, 'production.py'), production_settings_template, template_vars)
+        self.create_file(os.path.join(project_dir, 'staging.py'), production_settings_template, template_vars)
         
         # Create the static directory
         os.makedirs(os.path.join(project_dir, 'static'))
@@ -532,8 +533,9 @@ class Recipe(object):
 
         # Add the project that we are creating
         if self.options.has_key('project'):
-            project_src_path = os.path.join(self.buildout['buildout']['cwd'], 'src')
-            extra_paths.append(project_src_path)
+            
+            project_src_path = [os.path.join(self.buildout['buildout']['cwd'], 'src'), os.path.join(self.buildout['buildout']['cwd'], 'src', self.options['project']),]
+            extra_paths.extend(project_src_path)
         
         # Add libraries found by a site .pth files to our extra-paths.
         if 'pth-files' in self.options:
